@@ -1,5 +1,7 @@
 from importlib import import_module
 
+from memorious.core import connect_redis
+
 
 class CrawlerStage(object):
     """A single step in a data processing crawler."""
@@ -24,5 +26,15 @@ class CrawlerStage(object):
         module = import_module(package)
         return getattr(module, method)
 
+    @property
+    def op_count(self):
+        """Total operations performed for this stage"""
+        conn = connect_redis()
+        if conn is None:
+            return None
+        total_ops = conn.get(self.crawler.name + ":" + self.name)
+        if total_ops:
+            return int(total_ops)
+
     def __repr__(self):
         return '<CrawlerStage(%r, %s)>' % (self.crawler, self.name)
