@@ -35,12 +35,5 @@ class Result(Base):
         pq = pq.filter(cls.crawler == crawler)
         pq.delete(synchronize_session=False)
 
-    @classmethod
-    def by_crawler_next_stage(cls, crawler, next_stage):
-        q = session.query(cls)
-        q = q.filter(cls.crawler == crawler)
-        q = q.filter(cls.next_stage == next_stage)
-        return q
-
     def __repr__(self):
         return '<Result(%s,%s)>' % (self.crawler, self.next_stage)
